CA17-Cl01
open | /cms/logout |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Photos |
clickAndWait | link=Añadir foto |
type | id_name | CA17-Cl01 photo
select | id_status | label=Publicado
type | id_image | C:\Documents and Settings\mrivera\Escritorio\Merengue\test-data\test_image.jpg
clickAndWait | _save |
verifyTextPresent | CA17-Cl01 photo (test_image.jpg) |
verifyText | link=CA17-Cl01 photo (test_image.jpg) | CA17-Cl01 photo (test_image.jpg)
clickAndWait | link=CA17-Cl01 photo (test_image.jpg) |
type | id_name | CA17-Cl01B photo edited
clickAndWait | _save |
verifyTextNotPresent | CA17-Cl01 photo (test_image.jpg) |
verifyTextNotPresent | link=CA17-Cl01 photo (test_image.jpg) | CA17-Cl01 photo (test_image.jpg)
verifyTextPresent | CA17-Cl01B photo edited (test_image.jpg) |
verifyText | link=CA17-Cl01B photo edited (test_image.jpg) | CA17-Cl01B photo edited (test_image.jpg)
clickAndWait | link=CA17-Cl01B photo edited (test_image.jpg) |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |